==> Cosmos.uv3.02.tar.gz: cosmos/Zevhnp.h <==
c            hadronic collision parameters 
c	(->  ---------------------------------------------

        real*8  Cepic0  !2  Charge exchange prob. of pi+- --> pi0
        real*8  Cekaon  !2  Charge exchange prob. of kaon k+- -> k0
        real*8  Ceneuc  !2  p -> n ; n-> p; p~->n~; n~->p~ prob.
        real*8  Mudirp  !2  DD~ # enhancement factor. D is only for prompt muon.
     	real*8  Kpilog  !2  k-ch/pi-ch=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= effective s.
                        !      s'(GeV**2)=s - 4.63.  See also Kpicns.
        real*8  Kpicns  !2  See Kpilog.
        real*8  Elund   !2  E < Elund==> Lund M.C is used. in h-n. (IntModel='int1'). If IntModel='int2'
                        !   ==>Gheisha is used.  Elund can be as small as 4.99. (Default is  500.
                        !   For NEXT 4.99).
        real*8  Elund2  !2  Elund < E < Elund2 ==> ad hoc model is used; Elund2 must be > ~100, if Elund2 < Elund3.
                        !   Defualt is Elund
        real*8  Elund3  !2  Elund2< E < Elund3 ==> New Lund Fritiof is used. Elund3 can be < Elund2
                        !   If E > Elund3,  ad hoc model is used.  Default is Elund.
	real*8  Efermi   !2 If Kinetic E < Efermi, Fermi Momentum is considered for Nucleus target.
        character*6  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
                       ! for hadronic interactions.  If 'int2' Gheisha code is used for hadronic interactions,
                       ! at low energies. (See, Elund?).
        real*8 SucPw   !2  In the 2nd, 3rd,.. collision of a nucleon inside a nucleus, the collision is 
                       !  made to be more elastic than normal one. The leading particle spectrum is
                       ! sampled from x**SucPw dx. SucPw should be in 1 to 2.
        integer MulLow !2 if 1, QCD predicted multiplicity low is used in the adhoc model else UA5
                       !  parametalization is used. Default is 0. 
                       !  0.6135exp(23/18sqrt(2log(roots/0.3))) is QCD jet prediction. 
                       !  7.2roots**0.254 -7 is UA5 data. The branch point is set at roots = 900 GeV. 
                       !  (I have adjusted 0.6135 so that 900 GeV is the b.p)
        integer LundPara !2 To control Lund program. LundPara(1) is set to kfr(7); kfr(7)=1 is for Frititof hard
                       ! scattering. 2 is for Pythia H.S.  2 gives higher multiplicity but shape is strange.
                       ! default is 1. LundPara(2) is set to kfr(12): 1 by for OPAL hard scattering 
                       ! parameterization. 2 by DELPHI. Default is 2. (2 gives bit higher PT). LundPara(3) >
                       ! 0 =>Pythia message will appear.  LundPara(4) >0 Fritiof message; both on ErrorOut.
                       ! LundPara(5) =0 ==>All kaons collisions are treated as pi- in Fritiof, else they
                       ! are treated by adhoc model as they are.
c	<-)     -----------------------------
 
        common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog,
     *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
     *         LundPara(10)
        common /Zevhnc/ IntModel 
c                 this should be in block common. 
c        data  Cepic0/0.3d0/, Cekaon/0.d0/, Ceneuc/0.35d0/,
c    *         Mudirp/1.d0/, Kpilog/0.0062/, Kpicns/0.077/,
c    *         Efermi/2.d0/

==> Cosmos.uv3.50.tar.gz: cosmos/Zevhnp.h <==
c            hadronic collision parameters 
c	(->  ---------------------------------------------

        real*8  Cepic0  !2  Charge exchange prob. of pi+- --> pi0
        real*8  Cekaon  !2  Charge exchange prob. of kaon k+- -> k0
        real*8  Ceneuc  !2  p -> n ; n-> p; p~->n~; n~->p~ prob.
        real*8  Mudirp  !2  DD~ # enhancement factor. D is only for prompt muon.
     	real*8  Kpilog  !2  k-ch/pi-ch=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= effective s.
                        !      s'(GeV**2)=s - 4.63.  See also Kpicns.
        real*8  Kpicns  !2  See Kpilog.
        real*8  Elund   !2  E < Elund==> Lund M.C is used. in h-n. (IntModel='int1'). If IntModel='int2'
                        !   ==>Gheisha is used.  Elund can be as small as 4.99. (Default is  500.
                        !   For NEXT 4.99).
        real*8  Elund2  !2  Elund < E < Elund2 ==> ad hoc model is used; Elund2 must be > ~100, if Elund2 < Elund3.
                        !   Defualt is Elund
        real*8  Elund3  !2  Elund2< E < Elund3 ==> New Lund Fritiof is used. Elund3 can be < Elund2
                        !   If E > Elund3,  ad hoc model is used.  Default is Elund.
	real*8  Efermi   !2 If Kinetic E < Efermi, Fermi Momentum is considered for Nucleus target.
        character*6  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
                       ! for hadronic interactions.  If 'int2' Gheisha code is used for hadronic interactions,
                       ! at low energies. (See, Elund?).
        real*8 SucPw   !2  In the 2nd, 3rd,.. collision of a nucleon inside a nucleus, the collision is 
                       !  made to be more elastic than normal one. The leading particle spectrum is
                       ! sampled from x**SucPw dx. SucPw should be in 1 to 2.
        real*8  Eta2Pi0 !2  eta/pi0 ratio. this is used to see the effect due to non-decay of pi0
                      ! at very high energies. Only soruce of h.e gamma can be eta and LPM may work
                      ! for them. default is 0.2
        integer MulLow !2 if 1, QCD predicted multiplicity low is used in the adhoc model else UA5
                       !  parametalization is used. Default is 0. 
                       !  0.6135exp(23/18sqrt(2log(roots/0.3))) is QCD jet prediction. 
                       !  7.2roots**0.254 -7 is UA5 data. The branch point is set at roots = 900 GeV. 
                       !  (I have adjusted 0.6135 so that 900 GeV is the b.p)
        integer LundPara !2 To control Lund program. LundPara(1) is set to kfr(7); kfr(7)=1 is for Frititof hard
                       ! scattering. 2 is for Pythia H.S.  2 gives higher multiplicity but shape is strange.
                       ! default is 1. LundPara(2) is set to kfr(12): 1 by for OPAL hard scattering 
                       ! parameterization. 2 by DELPHI. Default is 2. (2 gives bit higher PT). LundPara(3) >
                       ! 0 =>Pythia message will appear.  LundPara(4) >0 Fritiof message; both on ErrorOut.
                       ! LundPara(5) =0 ==>All kaons collisions are treated as pi- in Fritiof, else they
                       ! are treated by adhoc model as they are.
c	<-)     -----------------------------
 
        common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
     *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
     *         LundPara(10)
        common /Zevhnc/ IntModel 
c                 this should be in block common. 
c        data  Cepic0/0.3d0/, Cekaon/0.d0/, Ceneuc/0.35d0/,
c    *         Mudirp/1.d0/, Kpilog/0.0062/, Kpicns/0.077/,
c    *         Efermi/2.d0/
